@@ -168,6 +168,10 @@ define([
                     code: 'from pandas_profiling import ProfileReport',
                     type: 'package'
                 },
+                'sweetviz': {
+                    code: 'import sweetviz',
+                    type: 'package'
+                },
                 'px': {
                     code: 'import plotly.express as px\nfrom plotly.offline import init_notebook_mode\ninit_notebook_mode(connected=True)',
                     type: 'package'
@@ -187,6 +191,10 @@ define([
                 'Counter': {
                     code: 'from collections import Counter',
                     type: 'package'
+                },
+                'joblib': {
+                    code: 'import joblib',
+                    type: 'package'
                 }
             }
 
@@ -958,7 +966,7 @@ define([
     /**
      * Version
      */
-    Config.version = "2.3.3";
+    Config.version = "2.3.4";
 
     /**
      * Type of mode
